[gegl/mrg_ui] ui: rename s/o->gegl_path/o->save_path/
- From: Øyvind Kolås <ok src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gegl/mrg_ui] ui: rename s/o->gegl_path/o->save_path/
- Date: Mon, 3 Aug 2015 18:02:29 +0000 (UTC)
commit 8290aa1b0d921a9c6107a3e3916be0ff97dfca74
Author: Oyvind Kolas <pippin gimp org>
Date: Mon Aug 3 18:38:52 2015 +0200
ui: rename s/o->gegl_path/o->save_path/
bin/mrg-ui.c | 30 +++++++++++++++---------------
1 files changed, 15 insertions(+), 15 deletions(-)
---
diff --git a/bin/mrg-ui.c b/bin/mrg-ui.c
index f002eaa..a96398f 100644
--- a/bin/mrg-ui.c
+++ b/bin/mrg-ui.c
@@ -59,7 +59,7 @@ struct _State {
Mrg *mrg;
char *path;
- char *gegl_path;
+ char *save_path;
GeglBuffer *buffer;
GeglNode *gegl;
@@ -994,21 +994,21 @@ static void load_path (State *o)
char *meta;
if (is_gegl_path (o->path))
{
- if (o->gegl_path)
- free (o->gegl_path);
- o->gegl_path = o->path;
- o->path = unsuffix_path (o->gegl_path);
+ if (o->save_path)
+ free (o->save_path);
+ o->save_path = o->path;
+ o->path = unsuffix_path (o->save_path);
}
else
{
- if (o->gegl_path)
- free (o->gegl_path);
- o->gegl_path = suffix_path (o->path);
+ if (o->save_path)
+ free (o->save_path);
+ o->save_path = suffix_path (o->path);
}
path = o->path;
- if (access (o->gegl_path, F_OK) != -1)
- path = o->gegl_path;
+ if (access (o->save_path, F_OK) != -1)
+ path = o->save_path;
g_object_unref (o->gegl);
o->gegl = NULL;
@@ -1065,7 +1065,7 @@ static void load_path (State *o)
NULL);
o->save = gegl_node_new_child (o->gegl,
"operation", "gegl:save",
- "path", o->gegl_path,
+ "path", o->save_path,
NULL);
gegl_node_link_many (o->load, o->source, o->sink, NULL);
gegl_node_set (o->load, "buffer", o->buffer, NULL);
@@ -1138,12 +1138,12 @@ static void go_parent (State *o)
static void go_prev (State *o)
{
char *lastslash;
- if (access (o->gegl_path, F_OK) != -1)
+ if (access (o->save_path, F_OK) != -1)
{
/* we need to skip from the -gegl one, when walking the dir alphabetically backwards */
char *tmp = o->path;
- o->path = o->gegl_path;
- o->gegl_path = tmp;
+ o->path = o->save_path;
+ o->save_path = tmp;
}
lastslash = strrchr (o->path, '/');
if (lastslash)
@@ -1642,7 +1642,7 @@ void gegl_node_defaults (GeglNode *node)
#endif
/* loads the source image corresponding to o->path into o->buffer and
* creates live gegl pipeline, or nops.. rigs up o->gegl_path to be
* the location where default saves ends up.
*/
void
@@ -1642,7 +1642,7 @@ void gegl_node_defaults (GeglNode *node)
#endif
/* loads the source image corresponding to o->path into o->buffer and
- * creates live gegl pipeline, or nops.. rigs up o->gegl_path to be
+ * creates live gegl pipeline, or nops.. rigs up o->save_path to be
* the location where default saves ends up.
*/
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]